"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class LiftedIteratorResourceImpl {
    constructor(dispatcher, disposable, observable) {
        this.dispatcher = dispatcher;
        this.disposable = disposable;
        this.observable = observable;
    }
    get isDisposed() {
        return this.disposable.isDisposed;
    }
    get subscriberCount() {
        return this.observable.subscriberCount;
    }
    add(disposable, ...disposables) {
        this.disposable.add(disposable, ...disposables);
    }
    dispatch(req) {
        this.dispatcher(req);
    }
    dispose() {
        this.disposable.dispose();
    }
    remove(disposable, ...disposables) {
        this.disposable.remove(disposable, ...disposables);
    }
    subscribe(subscriber) {
        this.observable.subscribe(subscriber);
    }
}
const liftImpl = (operator, dispatchOperator) => iterator => {
    const observable = iterator.observable || iterator;
    const dispatcher = iterator.dispatcher || ((req) => iterator.dispatch(req));
    const disposable = iterator.disposable || iterator;
    const liftedObservable = operator !== undefined ? operator(observable) : observable;
    const liftedDispatcher = dispatchOperator !== undefined
        ? dispatchOperator(dispatcher)
        : dispatcher;
    return new LiftedIteratorResourceImpl(liftedDispatcher, disposable, liftedObservable);
};
exports.lift = (operator) => liftImpl(operator, undefined);
exports.liftReq = (operator) => liftImpl(undefined, operator);
//# sourceMappingURL=index.js.map